==> okteta_14.12.3.orig.tar.xz: okteta-14.12.3/kasten/controllers/view/info/infotoolview.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef INFOTOOLVIEW_H
#define INFOTOOLVIEW_H

// lib
#include "oktetakastencontrollers_export.h"
// Kasten gui
#include <abstracttoolview.h>


namespace Kasten
{

class InfoView;
class InfoTool;


class OKTETAKASTENCONTROLLERS_EXPORT InfoToolView : public AbstractToolView
{
  public:
    explicit InfoToolView( InfoTool* tool );
    virtual ~InfoToolView();

  public: // AbstractToolView API
    virtual QWidget* widget() const;
    virtual QString title() const;
    virtual AbstractTool* tool() const;

  private:
    InfoView* mWidget;
};

}

#endif

==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/kasten/controllers/view/info/infotoolview.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef INFOTOOLVIEW_H
#define INFOTOOLVIEW_H

// lib
#include <kasten/okteta/oktetakastencontrollers_export.h>
// Kasten gui
#include <kasten/abstracttoolview.h>


namespace Kasten
{

class InfoView;
class InfoTool;


class OKTETAKASTENCONTROLLERS_EXPORT InfoToolView : public AbstractToolView
{
  public:
    explicit InfoToolView( InfoTool* tool );
    virtual ~InfoToolView();

  public: // AbstractToolView API
    virtual QWidget* widget() const;
    virtual QString title() const;
    virtual AbstractTool* tool() const;

  private:
    InfoView* mWidget;
};

}

#endif
